@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2011 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -26,10 +26,7 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 
 package Config::Model::Tk::AnyViewer ;
-{
-  $Config::Model::Tk::AnyViewer::VERSION = '1.339';
-}
-
+$Config::Model::Tk::AnyViewer::VERSION = '1.341';
 use strict;
 use warnings ;
 use Carp ;
@@ -131,8 +128,8 @@ sub add_help {
     chomp $help ;
 #    if (  $force_text_widget eq 'pod' or $help =~ /\n=\w+|[A-Z]</ ) {
     if ($force_text_widget or $help =~ /\n/ or length($help) > 50) {
-        $widget = $help_frame->PodText;
-        $widget ->pack( @fbe1 ) ;
+        $widget = $help_frame->PodText(-height => 5, -scrollbars  => 'oe');
+        $widget ->pack( @fxe1 ) ;
         $cw->update_help($widget, $help) ;
     }
     # elsif ($force_text_widget or $help =~ /\n/ or length($help) > 50) {
@@ -148,7 +145,7 @@ sub add_help {
         # $widget
           # ->tagConfigure(qw/help -lmargin1 2 -lmargin2 2 -rmargin 2/);
     # }
-    else {
+    elsif ($help =~ /\w/) {
         $widget = $help_frame->Label( -text => $help,
                                       -justify => 'left',
                                       -font => $text_font ,
