@@ -1,17 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2011 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::LeafEditor ;
-{
-  $Config::Model::Tk::LeafEditor::VERSION = '1.339';
-}
-
+$Config::Model::Tk::LeafEditor::VERSION = '1.341';
 use strict;
 use warnings ;
 use Carp ;
@@ -127,6 +124,7 @@ sub Populate {
     $cw->add_summary($leaf)->pack(@fx) ;
     $cw->add_description($leaf)->pack(@fx) ;
     my ($help_frame, $help_widget) = $cw->add_help('help on value' => '',1);
+    $help_frame->pack(@fx) ;
 
     $cw->Advertise( value_help_widget  => $help_widget );
     $cw->Advertise( value_help_frame   => $help_frame  );
