@@ -1,17 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2011 by Dominique Dumont.
+# This software is Copyright (c) 2014 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::ListEditor ;
-{
-  $Config::Model::Tk::ListEditor::VERSION = '1.339';
-}
-
+$Config::Model::Tk::ListEditor::VERSION = '1.341';
 use strict;
 use warnings ;
 use Carp ;
@@ -93,6 +90,7 @@ sub Populate {
     $cw->ConfigModelNoteEditor( -object => $list )->pack;
     $cw->add_summary($list)->pack(@fx);
     $cw->add_description($list)->pack(@fx);
+    $cw->add_warning($list, 'edit')->pack(@fx) ;
     $cw->add_info_button($cw)->pack(@fx);
 
     my $mv_rm_frame = $right_frame->Frame->pack(@fx);
